"""Controls all handling of time variables"""
import time

from time_conversions import hhmm_to_seconds
from time_conversions import hhmmss_to_seconds


def current_time_hhmmss() -> str:
    """Returns the current time in the format hh:mm:ss

    This function takes the hour, minute, and second components of the
    time.gmtime() seconds since epoch (in the struct_time format),
    converts them to strings, and concatenates them together with
    colons in between each segment.
    This is the returned as a string in the format hh:mm:ss
    where hh, mm, ss are hours, minutes, and seconds respectively.
    """
    return str(time.gmtime().tm_hour) \
        + ":" + str(time.gmtime().tm_min) \
        + ":" + str(time.gmtime().tm_sec)


def calc_sched_time(alarm_time: str,
                    current_time: str = current_time_hhmmss()) -> int:
    """Calculates the time in seconds until an alarm

    This function takes a given time for an alarm (in the format
    hh:mm), and the current time (in the format hh:mm:ss)(the current
    time is provided by the current_time_hhmmss function) as arguments.
    It then converts both of these times into the number of seconds past
    midnight for that day e.g. 13:37 would be 49020).
    Once it has converted both times, it calculates the time in seconds
    until that alarm is scheduled to trigger.
    """
    alarm_time_sec = hhmm_to_seconds(alarm_time)
    current_time_sec = hhmmss_to_seconds(current_time)
    time_to_sched = alarm_time_sec - current_time_sec
    # If the time is negative (i.e. the alarm is for a time before the
    # current time, i.e. if I set an alarm for 11:00 at 12:00, that
    # alarm is scheduled for the next day at 11:00.
    # This is achieved by adding 24 hours in seconds to the output.
    if time_to_sched <= 0:
        time_to_sched += 86400
    return time_to_sched


# a = calc_sched_time("14:13",)
# print(a)
